# Generated by Django 3.0.14 on 2022-04-11 10:53

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('invoice', '0006_detailpaymentinvoice_historicaldetailpaymentinvoice_historicalpaymentinvoice_paymentinvoice'),
    ]

    operations = [
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='subject_type',
            field=models.ForeignKey(db_column='SubjectType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='subject_type_payment', to='contenttypes.ContentType'),
        ),
    ]
