# Generated by Django 4.2.9 on 2024-02-07 16:47

import core.fields
import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('contenttypes', '0002_remove_content_type_name'),
        ('invoice', '0012_auto_20230921_0835'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bill',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='date_bill',
            field=core.fields.DateField(blank=True, db_column='DateBill', default=datetime.date.today, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='date_due',
            field=core.fields.DateField(blank=True, db_column='DateDue', null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='date_payed',
            field=core.fields.DateField(blank=True, db_column='DatePayed', null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='payment_reference',
            field=models.CharField(blank=True, db_column='PaymentReference', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='subject_id',
            field=models.CharField(blank=True, db_column='SubjectId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='subject_type',
            field=models.ForeignKey(blank=True, db_column='SubjectType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='subject_type_bill', to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='bill',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='thirdparty_id',
            field=models.CharField(blank=True, db_column='ThirdpartyId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='bill',
            name='thirdparty_type',
            field=models.ForeignKey(blank=True, db_column='ThirdpartyType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='bill',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='bill',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billevent',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='billevent',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='billevent',
            name='message',
            field=models.CharField(blank=True, db_column='Message', max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='billevent',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billevent',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='amount_total',
            field=models.DecimalField(db_column='AmountTotal', decimal_places=2, default=0.0, max_digits=18),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='details',
            field=models.JSONField(blank=True, db_column='Details', null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='ledger_account',
            field=models.CharField(blank=True, db_column='LedgerAccount', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='line_id',
            field=models.CharField(blank=True, db_column='LineId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='line_type',
            field=models.ForeignKey(blank=True, db_column='LineType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='line_type_bill', to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='tax_rate',
            field=models.UUIDField(blank=True, db_column='CalculationUUID', null=True),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billitem',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='amount_payed',
            field=models.DecimalField(blank=True, db_column='AmountPayed', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='amount_received',
            field=models.DecimalField(blank=True, db_column='AmountReceived', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='code_receipt',
            field=models.CharField(blank=True, db_column='CodeReceipt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='date_payment',
            field=core.fields.DateField(blank=True, db_column='DatePayment', null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='label',
            field=models.CharField(blank=True, db_column='Label', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='payment_origin',
            field=models.CharField(blank=True, db_column='PaymentOrigin', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='billpayment',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='amount',
            field=models.DecimalField(blank=True, db_column='Amount', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='reconcilation_date',
            field=models.DateField(blank=True, db_column='ReconcilationDate', null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='reconcilation_id',
            field=models.CharField(blank=True, db_column='ReconcilationId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='subject_id',
            field=models.CharField(blank=True, db_column='SubjectId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='subject_type',
            field=models.ForeignKey(blank=True, db_column='SubjectType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='subject_type_payment', to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='date_bill',
            field=core.fields.DateField(blank=True, db_column='DateBill', default=datetime.date.today, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='date_due',
            field=core.fields.DateField(blank=True, db_column='DateDue', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='date_payed',
            field=core.fields.DateField(blank=True, db_column='DatePayed', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='payment_reference',
            field=models.CharField(blank=True, db_column='PaymentReference', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='subject_id',
            field=models.CharField(blank=True, db_column='SubjectId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='thirdparty_id',
            field=models.CharField(blank=True, db_column='ThirdpartyId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillevent',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillevent',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillevent',
            name='message',
            field=models.CharField(blank=True, db_column='Message', max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='amount_total',
            field=models.DecimalField(db_column='AmountTotal', decimal_places=2, default=0.0, max_digits=18),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='details',
            field=models.JSONField(blank=True, db_column='Details', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='ledger_account',
            field=models.CharField(blank=True, db_column='LedgerAccount', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='line_id',
            field=models.CharField(blank=True, db_column='LineId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='tax_rate',
            field=models.UUIDField(blank=True, db_column='CalculationUUID', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='amount_payed',
            field=models.DecimalField(blank=True, db_column='AmountPayed', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='amount_received',
            field=models.DecimalField(blank=True, db_column='AmountReceived', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='code_receipt',
            field=models.CharField(blank=True, db_column='CodeReceipt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='date_payment',
            field=core.fields.DateField(blank=True, db_column='DatePayment', null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='label',
            field=models.CharField(blank=True, db_column='Label', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='payment_origin',
            field=models.CharField(blank=True, db_column='PaymentOrigin', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='amount',
            field=models.DecimalField(blank=True, db_column='Amount', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='reconcilation_date',
            field=models.DateField(blank=True, db_column='ReconcilationDate', null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='reconcilation_id',
            field=models.CharField(blank=True, db_column='ReconcilationId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='subject_id',
            field=models.CharField(blank=True, db_column='SubjectId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='date_due',
            field=core.fields.DateField(blank=True, db_column='DateDue', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='date_invoice',
            field=core.fields.DateField(blank=True, db_column='DateInvoice', default=datetime.date.today, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='date_payed',
            field=core.fields.DateField(blank=True, db_column='DatePayed', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='payment_reference',
            field=models.CharField(blank=True, db_column='PaymentReference', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='subject_id',
            field=models.CharField(blank=True, db_column='SubjectId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='thirdparty_id',
            field=models.CharField(blank=True, db_column='ThirdpartyId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoiceevent',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoiceevent',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoiceevent',
            name='message',
            field=models.CharField(blank=True, db_column='Message', max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='amount_total',
            field=models.DecimalField(db_column='AmountTotal', decimal_places=2, default=0.0, max_digits=18),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='details',
            field=models.JSONField(blank=True, db_column='Details', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='ledger_account',
            field=models.CharField(blank=True, db_column='LedgerAccount', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='line_id',
            field=models.CharField(blank=True, db_column='LineId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='tax_rate',
            field=models.UUIDField(blank=True, db_column='CalculationUUID', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='amount_payed',
            field=models.DecimalField(blank=True, db_column='AmountPayed', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='amount_received',
            field=models.DecimalField(blank=True, db_column='AmountReceived', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='code_receipt',
            field=models.CharField(blank=True, db_column='CodeReceipt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='date_payment',
            field=core.fields.DateField(blank=True, db_column='DatePayment', null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='label',
            field=models.CharField(blank=True, db_column='Label', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='payment_origin',
            field=models.CharField(blank=True, db_column='PaymentOrigin', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='amount_received',
            field=models.DecimalField(blank=True, db_column='AmountReceived', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='code_receipt',
            field=models.CharField(blank=True, db_column='CodeReceipt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='date_payment',
            field=core.fields.DateField(blank=True, db_column='DatePayment', null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='label',
            field=models.CharField(blank=True, db_column='Label', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='payer_name',
            field=models.CharField(blank=True, db_column='PayerName', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='payment_origin',
            field=models.CharField(blank=True, db_column='PaymentOrigin', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='date_due',
            field=core.fields.DateField(blank=True, db_column='DateDue', null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='date_invoice',
            field=core.fields.DateField(blank=True, db_column='DateInvoice', default=datetime.date.today, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='date_payed',
            field=core.fields.DateField(blank=True, db_column='DatePayed', null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='payment_reference',
            field=models.CharField(blank=True, db_column='PaymentReference', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='subject_id',
            field=models.CharField(blank=True, db_column='SubjectId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='subject_type',
            field=models.ForeignKey(blank=True, db_column='SubjectType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='subject_type', to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='thirdparty_id',
            field=models.CharField(blank=True, db_column='ThirdpartyId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='thirdparty_type',
            field=models.ForeignKey(blank=True, db_column='ThirdpartyType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoiceevent',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoiceevent',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoiceevent',
            name='message',
            field=models.CharField(blank=True, db_column='Message', max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='invoiceevent',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoiceevent',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='amount_total',
            field=models.DecimalField(db_column='AmountTotal', decimal_places=2, default=0.0, max_digits=18),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='details',
            field=models.JSONField(blank=True, db_column='Details', null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='ledger_account',
            field=models.CharField(blank=True, db_column='LedgerAccount', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='line_id',
            field=models.CharField(blank=True, db_column='LineId', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='line_type',
            field=models.ForeignKey(blank=True, db_column='LineType', null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='line_type', to='contenttypes.contenttype'),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='replacement_uuid',
            field=models.UUIDField(blank=True, db_column='ReplacementUUID', null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='tax_analysis',
            field=models.JSONField(blank=True, db_column='TaxAnalysis', null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='tax_rate',
            field=models.UUIDField(blank=True, db_column='CalculationUUID', null=True),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoicelineitem',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='amount_payed',
            field=models.DecimalField(blank=True, db_column='AmountPayed', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='amount_received',
            field=models.DecimalField(blank=True, db_column='AmountReceived', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='code_receipt',
            field=models.CharField(blank=True, db_column='CodeReceipt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='date_payment',
            field=core.fields.DateField(blank=True, db_column='DatePayment', null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='label',
            field=models.CharField(blank=True, db_column='Label', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='payment_origin',
            field=models.CharField(blank=True, db_column='PaymentOrigin', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='invoicepayment',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='amount_received',
            field=models.DecimalField(blank=True, db_column='AmountReceived', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='code_ext',
            field=models.CharField(blank=True, db_column='CodeExt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='code_receipt',
            field=models.CharField(blank=True, db_column='CodeReceipt', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='code_tp',
            field=models.CharField(blank=True, db_column='CodeTp', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='date_created',
            field=core.fields.DateTimeField(db_column='DateCreated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='date_payment',
            field=core.fields.DateField(blank=True, db_column='DatePayment', null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='date_updated',
            field=core.fields.DateTimeField(db_column='DateUpdated', default=datetime.datetime.now, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='fees',
            field=models.DecimalField(blank=True, db_column='Fees', decimal_places=2, max_digits=18, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='label',
            field=models.CharField(blank=True, db_column='Label', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='payer_name',
            field=models.CharField(blank=True, db_column='PayerName', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='payment_origin',
            field=models.CharField(blank=True, db_column='PaymentOrigin', max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='user_created',
            field=models.ForeignKey(db_column='UserCreatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_created', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='paymentinvoice',
            name='user_updated',
            field=models.ForeignKey(db_column='UserUpdatedUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='%(class)s_user_updated', to=settings.AUTH_USER_MODEL),
        ),
    ]
