# Generated by Django 3.0.14 on 2022-04-11 13:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('invoice', '0007_auto_20220411_1053'),
    ]

    operations = [
        migrations.AlterField(
            model_name='detailpaymentinvoice',
            name='payment',
            field=models.ForeignKey(db_column='PaymentUUID', on_delete=django.db.models.deletion.DO_NOTHING, related_name='invoice_payments', to='invoice.PaymentInvoice'),
        ),
    ]
