# Generated by Django 3.2.16 on 2023-01-26 09:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('invoice', '0009_auto_20220413_0824'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='historicalbill',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical bill', 'verbose_name_plural': 'historical bills'},
        ),
        migrations.AlterModelOptions(
            name='historicalbillevent',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical bill event', 'verbose_name_plural': 'historical bill events'},
        ),
        migrations.AlterModelOptions(
            name='historicalbillitem',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical bill item', 'verbose_name_plural': 'historical bill items'},
        ),
        migrations.AlterModelOptions(
            name='historicalbillpayment',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical bill payment', 'verbose_name_plural': 'historical bill payments'},
        ),
        migrations.AlterModelOptions(
            name='historicaldetailpaymentinvoice',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical detail payment invoice', 'verbose_name_plural': 'historical detail payment invoices'},
        ),
        migrations.AlterModelOptions(
            name='historicalinvoice',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical invoice', 'verbose_name_plural': 'historical invoices'},
        ),
        migrations.AlterModelOptions(
            name='historicalinvoiceevent',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical invoice event', 'verbose_name_plural': 'historical invoice events'},
        ),
        migrations.AlterModelOptions(
            name='historicalinvoicelineitem',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical invoice line item', 'verbose_name_plural': 'historical invoice line items'},
        ),
        migrations.AlterModelOptions(
            name='historicalinvoicepayment',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical invoice payment', 'verbose_name_plural': 'historical invoice payments'},
        ),
        migrations.AlterModelOptions(
            name='historicalpaymentinvoice',
            options={'get_latest_by': ('history_date', 'history_id'), 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical payment invoice', 'verbose_name_plural': 'historical payment invoices'},
        ),
        migrations.AlterField(
            model_name='historicalbill',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbillevent',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbillitem',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalbillpayment',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicaldetailpaymentinvoice',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoice',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoiceevent',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicelineitem',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalinvoicepayment',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
        migrations.AlterField(
            model_name='historicalpaymentinvoice',
            name='history_date',
            field=models.DateTimeField(db_index=True),
        ),
    ]
